@@ -5,7 +5,7 @@ var_type=1
 help_short="wslvar (--sys|--shell) [NAME]\nwslvar (--help|--version|--getsys|--getshell)"
 
 function call_shell {
-	winps_exec "(Get-ItemProperty 'HKCU:\Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders').'$@'" | cat
+	winps_exec "(Get-ItemProperty 'HKCU:\Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders').'$*'" | cat
 }
 
 function view_shell {
@@ -13,7 +13,7 @@ function view_shell {
 }
 
 function call_sys {
-	winps_exec "Write-Output \$Env:$@" | cat
+	winps_exec "Write-Output \$Env:$*" | cat
 }
 
 function view_sys {
@@ -25,13 +25,13 @@ function cl_destoryer {
 }
 
 function caller {
-	if [ "$@" != "" ]; then
+	if [ "$*" != "" ]; then
 		case $var_type in
-			1) p="$(cl_destoryer $(call_sys $@))";;
-			2) p="$(cl_destoryer $(call_shell $@))";;
+			1) p="$(cl_destoryer "$(call_sys "$@")")";;
+			2) p="$(cl_destoryer "$(call_shell "$@")")";;
 			*) echo "${error}Invalid variable type. Aborted."; exit 22;;
 		esac
-		echo $p
+		echo "$p"
 	else
 		echo "${error} No Input. Aborted."
 		exit 21
@@ -44,7 +44,7 @@ while [ "$1" != "" ]; do
 		-l|--shell) var_type=2; shift;;
 		-S|--getsys) view_sys; exit;;
 		-L|--getshell) view_shell; exit;;
-		-h|--help) help $0 "$help_short"; exit;;
+		-h|--help) help "$0" "$help_short"; exit;;
 		-v|--version) echo "wslu v$wslu_version; wslvar v$version"; exit;;
 		*) caller "$@"; exit;;
 	esac
